nltk.stem package
=================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.stem.api
   nltk.stem.arlstem
   nltk.stem.arlstem2
   nltk.stem.cistem
   nltk.stem.isri
   nltk.stem.lancaster
   nltk.stem.porter
   nltk.stem.regexp
   nltk.stem.rslp
   nltk.stem.snowball
   nltk.stem.util
   nltk.stem.wordnet

Module contents
---------------

.. automodule:: nltk.stem
   :members:
   :undoc-members:
   :show-inheritance:
